C Takes a (vector) cross product of vectors [H1 K1 L1] and [H2 K2 L2]
C   to generate vector [H3 K3 L3] 
C Converts all vectors to real space
C
C 
C Reference
C  Worked Examples in the Geometry of Crystals
C  by H. K. D. H. Bhadeshia
C  Published by the Institute of Materials, London, 1987.
C  See pages 23-24 including equation 10b for details.
C
      SUBROUTINE MAP_UTIL_CROSS(H1,K1,L1,JR1,H2,K2,L2,JR2
     &,H3,K3,L3,JR3,F,G)
      IMPLICIT NONE
      REAL H1,K1,L1,H2,K2,L2,H3,K3,L3,F(9),G(9),DEL,A,B,C,VOL
      INTEGER JR1,JR2,JR3

C JR1 and JR2 have values of 0 or 1 if real or reciprocal
C   lattice vectors respectively
C
C The metric tensor F converts the components from reciprocal to
C  real space. 
C The metric tensor G converts the components from real to reciprocal
C  space, and G is the inverse of F and vice-versa.
C
C Calculate volume of cell from the determinant of G
      CALL MAP_UTIL_DET(G,DEL)
      VOL=SQRT(DEL)
C
C Refer all vectors to real space coordinates if not already so.
      IF(JR1 .EQ. 1) GOTO 1
        GOTO 2
1     CALL MAP_UTIL_TRANS(F,H1,K1,L1,A,B,C)
          H1=A
          K1=B
          L1=C
2     IF(JR2 .EQ. 1) GOTO 3
        GOTO 4
3     CALL MAP_UTIL_TRANS(F,H2,K2,L2,A,B,C)
          H2=A
          K2=B
          L2=C
C
C Compute the vector resulting from cross product
4             H3=(K1*L2-L1*K2)*VOL
              K3=(L1*H2-H1*L2)*VOL
              L3=(H1*K2-H2*K1)*VOL
C
C Convert components of resultant vector to real space coordinates
      CALL MAP_UTIL_TRANS(F,H3,K3,L3,A,B,C)
              H3=A
              K3=B
              L3=C
C
C Reset basis indicators to imply that all vectors are referred
C  to real space coordinates
                JR2=0
                JR1=0
                JR3=0
C
      RETURN
      END
